@@ -1,6 +1,7 @@
+import moment, { Moment, MomentInput, DurationInputArg1, DurationInputArg2 } from 'moment';
+
 import { TimeZone } from '../types/time';
 /* eslint-disable id-blacklist, no-restricted-imports, @typescript-eslint/ban-types */
-import moment, { Moment, MomentInput, DurationInputArg1 } from 'moment';
 export interface DateTimeBuiltinFormat {
   __momentBuiltinFormatBrand: any;
 }
@@ -17,6 +18,7 @@ export type DurationUnit =
   | 'M'
   | 'week'
   | 'weeks'
+  | 'isoWeek'
   | 'w'
   | 'day'
   | 'days'
@@ -79,11 +81,26 @@ export const setLocale = (language: string) => {
   moment.locale(language);
 };
 
+export const getLocale = () => {
+  return moment.locale();
+};
+
 export const getLocaleData = (): DateTimeLocale => {
   return moment.localeData();
 };
 
-export const isDateTime = (value: any): value is DateTime => {
+export const isDateTimeInput = (value: unknown): value is DateTimeInput => {
+  return (
+    value === null ||
+    typeof value === 'string' ||
+    typeof value === 'number' ||
+    value instanceof Date ||
+    (Array.isArray(value) && value.every((v) => typeof v === 'string' || typeof v === 'number')) ||
+    isDateTime(value)
+  );
+};
+
+export const isDateTime = (value: unknown): value is DateTime => {
   return moment.isMoment(value);
 };
 
@@ -92,7 +109,8 @@ export const toUtc = (input?: DateTimeInput, formatInput?: FormatInput): DateTim
 };
 
 export const toDuration = (input?: DurationInput, unit?: DurationUnit): DateTimeDuration => {
-  return moment.duration(input as DurationInputArg1, unit) as DateTimeDuration;
+  // moment built-in types are a bit flaky, for example `isoWeek` is not in the type definition but it's present in the js source.
+  return moment.duration(input as DurationInputArg1, unit as DurationInputArg2) as DateTimeDuration;
 };
 
 export const dateTime = (input?: DateTimeInput, formatInput?: FormatInput): DateTime => {
@@ -114,3 +132,28 @@ export const dateTimeForTimeZone = (
 
   return dateTime(input, formatInput);
 };
+
+export const getWeekdayIndex = (day: string) => {
+  return moment.weekdays().findIndex((wd) => wd.toLowerCase() === day.toLowerCase());
+};
+
+export const getWeekdayIndexByEnglishName = (day: string) =>
+  ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'].findIndex(
+    (wd) => wd.toLowerCase() === day.toLowerCase()
+  );
+
+export const setWeekStart = (weekStart?: string) => {
+  const suffix = '-weekStart';
+  const language = getLocale().replace(suffix, '');
+  const dow = weekStart ? getWeekdayIndexByEnglishName(weekStart) : -1;
+  if (dow !== -1) {
+    moment.locale(language + suffix, {
+      parentLocale: language,
+      week: {
+        dow,
+      },
+    });
+  } else {
+    setLocale(language);
+  }
+};
