@@ -1,9 +1,10 @@
 import { getFieldDisplayName } from '../../field/fieldState';
 import { stringToJsRegex } from '../../text/string';
-import { Field, DataFrame, FieldType, TIME_SERIES_VALUE_FIELD_NAME } from '../../types/dataFrame';
-import { FieldMatcherInfo, FrameMatcherInfo, FieldMatcher } from '../../types/transformations';
+import { DataFrame, Field, FieldType, TIME_SERIES_VALUE_FIELD_NAME } from '../../types/dataFrame';
+import { FieldMatcher, FieldMatcherInfo, FrameMatcherInfo } from '../../types/transformations';
 
 import { FieldMatcherID, FrameMatcherID } from './ids';
+
 export interface RegexpOrNamesMatcherOptions {
   pattern?: string;
   names?: string[];
@@ -98,10 +99,10 @@ const multipleFieldNamesMatcher: FieldMatcherInfo<ByNamesMatcherOptions> = {
   },
 };
 
-// In an effor to support migrating to a consistent data contract, the
-// naming conventions need to get normalized.  However many existing setups
+// In an effort to support migrating to a consistent data contract, the
+// naming conventions need to get normalized. However, many existing setups
 // exist that would no longer match names if that changes.  This injects
-// fallback logic when when the data frame has not type version specified
+// fallback logic when the data frame has not type version specified
 export function fieldNameFallback(fields: Set<string>) {
   let fallback: FieldMatcher | undefined = undefined;
 
