@@ -1,9 +1,9 @@
-import { mockTransformationsRegistry } from '../../utils/tests/mockTransformationsRegistry';
-import { DataTransformerConfig, DisplayProcessor, Field, FieldType } from '../../types';
-import { DataTransformerID } from './ids';
 import { toDataFrame } from '../../dataframe';
+import { DataTransformerConfig, DisplayProcessor, Field, FieldType } from '../../types';
+import { mockTransformationsRegistry } from '../../utils/tests/mockTransformationsRegistry';
 import { transformDataFrame } from '../transformDataFrame';
-import { ArrayVector } from '../../vector';
+
+import { DataTransformerID } from './ids';
 import { mergeTransformer, MergeTransformerOptions } from './merge';
 
 describe('Merge multiple to single', () => {
@@ -16,6 +16,20 @@ describe('Merge multiple to single', () => {
     mockTransformationsRegistry([mergeTransformer]);
   });
 
+  it('skip combine one serie', async () => {
+    const seriesA = toDataFrame({
+      name: 'A',
+      fields: [
+        { name: 'Time', type: FieldType.time, values: [1000] },
+        { name: 'Temp', type: FieldType.number, values: [1] },
+      ],
+    });
+    await expect(transformDataFrame([cfg], [seriesA])).toEmitValuesWith((received) => {
+      const result = received[0];
+      expect(seriesA).toBe(result[0]);
+    });
+  });
+
   it('combine two series into one', async () => {
     const seriesA = toDataFrame({
       name: 'A',
@@ -140,7 +154,7 @@ describe('Merge multiple to single', () => {
       const expected: Field[] = [
         createField('Time', FieldType.time, [1000, 1000, 500]),
         createField('Temp', FieldType.number, [1, -1, 2]),
-        createField('Humidity', FieldType.number, [10, null, 5]),
+        createField('Humidity', FieldType.number, [10, undefined, 5]),
       ];
 
       expect(unwrap(result[0].fields)).toEqual(expected);
@@ -179,7 +193,7 @@ describe('Merge multiple to single', () => {
       const expected: Field[] = [
         createField('Time', FieldType.time, ['2019-10-01T11:10:23Z', '2019-09-01T11:10:23Z', '2019-11-01T11:10:23Z']),
         createField('Temp', FieldType.number, [1, -1, 2]),
-        createField('Humidity', FieldType.number, [10, null, 5]),
+        createField('Humidity', FieldType.number, [10, undefined, 5]),
       ];
 
       expect(unwrap(result[0].fields)).toEqual(expected);
@@ -222,7 +236,7 @@ describe('Merge multiple to single', () => {
           'Germany',
           'Canada',
           'Canada',
-          null,
+          undefined,
         ]),
         createField('AgeGroup', FieldType.string, [
           '50 or over',
@@ -233,7 +247,7 @@ describe('Merge multiple to single', () => {
           '25 - 34',
           '18 - 24',
         ]),
-        createField('Sum', FieldType.number, [998, 1193, 1675, 146, 166, 219, null]),
+        createField('Sum', FieldType.number, [998, 1193, 1675, 146, 166, 219, undefined]),
         createField('Count', FieldType.number, [2, 4, 1, 4, 4, 2, 3]),
       ];
 
@@ -284,17 +298,17 @@ describe('Merge multiple to single', () => {
           '35 - 49',
           '35 - 49',
         ]),
-        createField('Count', FieldType.number, [1, 3, 2, 4, 2, null, null]),
+        createField('Count', FieldType.number, [1, 3, 2, 4, 2, undefined, undefined]),
         createField('Country', FieldType.string, [
           'Mexico',
-          null,
+          undefined,
           'Canada',
           'United States',
           'United States',
           'Germany',
           'Canada',
         ]),
-        createField('Sum', FieldType.number, [1675, null, 219, 1193, 998, 146, 166]),
+        createField('Sum', FieldType.number, [1675, undefined, 219, 1193, 998, 146, 166]),
       ];
 
       expect(unwrap(result[0].fields)).toEqual(expected);
@@ -334,8 +348,18 @@ describe('Merge multiple to single', () => {
       const expected: Field[] = [
         createField('Time', FieldType.time, [100, 150, 200, 100, 125, 126, 100, 124, 149]),
         createField('Temp', FieldType.number, [1, 4, 5, -1, 2, 3, 1, 4, 5]),
-        createField('Humidity', FieldType.number, [10, 14, 55, null, null, null, 22, 25, 30]),
-        createField('Enabled', FieldType.boolean, [null, null, null, true, false, true, null, null, null]),
+        createField('Humidity', FieldType.number, [10, 14, 55, undefined, undefined, undefined, 22, 25, 30]),
+        createField('Enabled', FieldType.boolean, [
+          undefined,
+          undefined,
+          undefined,
+          true,
+          false,
+          true,
+          undefined,
+          undefined,
+          undefined,
+        ]),
       ];
 
       expect(unwrap(result[0].fields)).toEqual(expected);
@@ -560,18 +584,16 @@ describe('Merge multiple to single', () => {
   });
 });
 
-const createField = (name: string, type: FieldType, values: any[], config = {}, display?: DisplayProcessor): Field => {
-  return { name, type, values: new ArrayVector(values), config, labels: undefined, display };
+const createField = (
+  name: string,
+  type: FieldType,
+  values: unknown[],
+  config = {},
+  display?: DisplayProcessor
+): Field => {
+  return { name, type, values: values, config, labels: undefined, display };
 };
 
 const unwrap = (fields: Field[]): Field[] => {
-  return fields.map((field) =>
-    createField(
-      field.name,
-      field.type,
-      field.values.toArray().map((value: any) => value),
-      field.config,
-      field.display
-    )
-  );
+  return fields.map((field) => createField(field.name, field.type, field.values, field.config, field.display));
 };
