@@ -2,7 +2,7 @@ import { Observable } from 'rxjs';
 
 import { DataQuery } from '@grafana/schema';
 
-import { Labels } from './data';
+import { KeyValue, Labels } from './data';
 import { DataFrame } from './dataFrame';
 import { DataQueryRequest, DataQueryResponse } from './datasource';
 import { AbsoluteTimeRange } from './time';
@@ -55,6 +55,9 @@ export interface LogRowModel {
   // the same as rows final index when rendered.
   rowIndex: number;
 
+  // The value of the the dataframe's id field, if it exists
+  rowId?: string;
+
   // Full DataFrame from which we parsed this log.
   // TODO: refactor this so we do not need to pass whole dataframes in addition to also parsed data.
   dataFrame: DataFrame;
@@ -260,3 +263,42 @@ export const hasLogsContextUiSupport = (datasource: unknown): datasource is Data
 
   return withLogsSupport.getLogRowContextUi !== undefined;
 };
+
+export interface QueryFilterOptions extends KeyValue<string> {}
+export interface ToggleFilterAction {
+  type: 'FILTER_FOR' | 'FILTER_OUT';
+  options: QueryFilterOptions;
+}
+/**
+ * Data sources that support toggleable filters through `toggleQueryFilter`, and displaying the active
+ * state of filters through `queryHasFilter`, in the Log Details component in Explore.
+ * @internal
+ * @alpha
+ */
+export interface DataSourceWithToggleableQueryFiltersSupport<TQuery extends DataQuery> {
+  /**
+   * Toggle filters on and off from query.
+   * If the filter is already present, it should be removed.
+   * If the opposite filter is present, it should be replaced.
+   */
+  toggleQueryFilter(query: TQuery, filter: ToggleFilterAction): TQuery;
+
+  /**
+   * Given a query, determine if it has a filter that matches the options.
+   */
+  queryHasFilter(query: TQuery, filter: QueryFilterOptions): boolean;
+}
+
+/**
+ * @internal
+ */
+export const hasToggleableQueryFiltersSupport = <TQuery extends DataQuery>(
+  datasource: unknown
+): datasource is DataSourceWithToggleableQueryFiltersSupport<TQuery> => {
+  return (
+    datasource !== null &&
+    typeof datasource === 'object' &&
+    'toggleQueryFilter' in datasource &&
+    'queryHasFilter' in datasource
+  );
+};
