@@ -163,7 +163,7 @@ export interface PanelOptionsEditorConfig<TOptions, TSettings = any, TValue = an
  * @internal
  */
 export interface PanelMenuItem {
-  type?: 'submenu' | 'divider';
+  type?: 'submenu' | 'divider' | 'group';
   text: string;
   iconClassName?: IconName;
   onClick?: (event: React.MouseEvent<any>) => void;
