@@ -49,6 +49,7 @@ export const getCategories = (): ValueFormatCategory[] => [
       { name: 'Percent (0.0-1.0)', id: 'percentunit', fn: toPercentUnit },
       { name: 'Humidity (%H)', id: 'humidity', fn: toFixedUnit('%H') },
       { name: 'Decibel', id: 'dB', fn: toFixedUnit('dB') },
+      { name: 'Candela (cd)', id: 'candela', fn: SIPrefix('cd') },
       { name: 'Hexadecimal (0x)', id: 'hex0x', fn: toHex0x },
       { name: 'Hexadecimal', id: 'hex', fn: toHex },
       { name: 'Scientific notation', id: 'sci', fn: sci },
@@ -80,6 +81,8 @@ export const getCategories = (): ValueFormatCategory[] => [
       { name: 'Square Meters (m²)', id: 'areaM2', fn: toFixedUnit('m²') },
       { name: 'Square Feet (ft²)', id: 'areaF2', fn: toFixedUnit('ft²') },
       { name: 'Square Miles (mi²)', id: 'areaMI2', fn: toFixedUnit('mi²') },
+      { name: 'Acres (ac)', id: 'acres', fn: toFixedUnit('ac') },
+      { name: 'Hectares (ha)', id: 'hectares', fn: toFixedUnit('ha') },
     ],
   },
   {
@@ -138,6 +141,7 @@ export const getCategories = (): ValueFormatCategory[] => [
       { name: 'Indonesian Rupiah (Rp)', id: 'currencyIDR', fn: currency('Rp') },
       { name: 'Philippine Peso (PHP)', id: 'currencyPHP', fn: currency('PHP') },
       { name: 'Vietnamese Dong (VND)', id: 'currencyVND', fn: currency('đ', true) },
+      { name: 'Turkish Lira (₺)', id: 'currencyTRY', fn: currency('₺', true) },
     ],
   },
   {
@@ -235,6 +239,7 @@ export const getCategories = (): ValueFormatCategory[] => [
       { name: 'Kilovolt (kV)', id: 'kvolt', fn: SIPrefix('V', 1) },
       { name: 'Millivolt (mV)', id: 'mvolt', fn: SIPrefix('V', -1) },
       { name: 'Decibel-milliwatt (dBm)', id: 'dBm', fn: SIPrefix('dBm') },
+      { name: 'Milliohm (mΩ)', id: 'mohm', fn: SIPrefix('Ω', -1) },
       { name: 'Ohm (Ω)', id: 'ohm', fn: SIPrefix('Ω') },
       { name: 'Kiloohm (kΩ)', id: 'kohm', fn: SIPrefix('Ω', 1) },
       { name: 'Megaohm (MΩ)', id: 'Mohm', fn: SIPrefix('Ω', 2) },
@@ -340,6 +345,9 @@ export const getCategories = (): ValueFormatCategory[] => [
     formats: [
       { name: 'Revolutions per minute (rpm)', id: 'rotrpm', fn: toFixedUnit('rpm') },
       { name: 'Hertz (Hz)', id: 'rothz', fn: SIPrefix('Hz') },
+      { name: 'Kilohertz (kHz)', id: 'rotkhz', fn: SIPrefix('Hz', 1) },
+      { name: 'Megahertz (MHz)', id: 'rotmhz', fn: SIPrefix('Hz', 2) },
+      { name: 'Gigahertz (GHz)', id: 'rotghz', fn: SIPrefix('Hz', 3) },
       { name: 'Radians per second (rad/s)', id: 'rotrads', fn: toFixedUnit('rad/s') },
       { name: 'Degrees per second (°/s)', id: 'rotdegs', fn: toFixedUnit('°/s') },
     ],
@@ -381,11 +389,19 @@ export const getCategories = (): ValueFormatCategory[] => [
       { name: 'reads/sec (rps)', id: 'rps', fn: simpleCountUnit('rd/s') },
       { name: 'writes/sec (wps)', id: 'wps', fn: simpleCountUnit('wr/s') },
       { name: 'I/O ops/sec (iops)', id: 'iops', fn: simpleCountUnit('io/s') },
+      { name: 'events/sec (eps)', id: 'eps', fn: simpleCountUnit('evt/s') },
+      { name: 'messages/sec (mps)', id: 'mps', fn: simpleCountUnit('msg/s') },
+      { name: 'records/sec (rps)', id: 'recps', fn: simpleCountUnit('rec/s') },
+      { name: 'rows/sec (rps)', id: 'rowsps', fn: simpleCountUnit('rows/s') },
       { name: 'counts/min (cpm)', id: 'cpm', fn: simpleCountUnit('c/m') },
       { name: 'ops/min (opm)', id: 'opm', fn: simpleCountUnit('ops/m') },
       { name: 'requests/min (rpm)', id: 'reqpm', fn: simpleCountUnit('req/m') },
       { name: 'reads/min (rpm)', id: 'rpm', fn: simpleCountUnit('rd/m') },
       { name: 'writes/min (wpm)', id: 'wpm', fn: simpleCountUnit('wr/m') },
+      { name: 'events/min (epm)', id: 'epm', fn: simpleCountUnit('evts/m') },
+      { name: 'messages/min (mpm)', id: 'mpm', fn: simpleCountUnit('msgs/m') },
+      { name: 'records/min (rpm)', id: 'recpm', fn: simpleCountUnit('rec/m') },
+      { name: 'rows/min (rpm)', id: 'rowspm', fn: simpleCountUnit('rows/m') },
     ],
   },
   {
