@@ -49,7 +49,7 @@ export interface CascaderOption {
   /**
    *  The value used under the hood
    */
-  value: any;
+  value: string;
   /**
    *  The label to display in the UI
    */
@@ -63,11 +63,11 @@ export interface CascaderOption {
   children?: CascaderOption[];
 }
 
-const disableDivFocus = css(`
-&:focus{
-  outline: none;
-}
-`);
+const disableDivFocus = css({
+  '&:focus': {
+    outline: 'none',
+  },
+});
 
 const DEFAULT_SEPARATOR = '/';
 
