@@ -1,6 +1,6 @@
 import { action } from '@storybook/addon-actions';
 import { useArgs } from '@storybook/client-api';
-import { ComponentMeta, ComponentStory } from '@storybook/react';
+import { Meta, StoryFn } from '@storybook/react';
 
 import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
 import { renderComponentWithTheme } from '../../utils/storybook/withTheme';
@@ -8,7 +8,7 @@ import { renderComponentWithTheme } from '../../utils/storybook/withTheme';
 import mdx from './ColorPicker.mdx';
 import SpectrumPalette from './SpectrumPalette';
 
-const meta: ComponentMeta<typeof SpectrumPalette> = {
+const meta: Meta<typeof SpectrumPalette> = {
   title: 'Pickers and Editors/ColorPicker/Palettes/SpectrumPalette',
   component: SpectrumPalette,
   decorators: [withCenteredStory],
@@ -25,7 +25,7 @@ const meta: ComponentMeta<typeof SpectrumPalette> = {
   },
 };
 
-export const Simple: ComponentStory<typeof SpectrumPalette> = ({ color }) => {
+export const Simple: StoryFn<typeof SpectrumPalette> = ({ color }) => {
   const [, updateArgs] = useArgs();
   return renderComponentWithTheme(SpectrumPalette, {
     color,
