@@ -1,4 +1,4 @@
-import { ComponentMeta } from '@storybook/react';
+import { Meta } from '@storybook/react';
 import React, { useState } from 'react';
 
 import { withCenteredStory } from '../../../utils/storybook/withCenteredStory';
@@ -7,7 +7,7 @@ import { Button } from '../../Button/Button';
 import { DatePicker, DatePickerProps } from './DatePicker';
 import mdx from './DatePicker.mdx';
 
-const meta: ComponentMeta<typeof DatePicker> = {
+const meta: Meta<typeof DatePicker> = {
   title: 'Pickers and Editors/TimePickers/Pickers And Editors/DatePicker',
   component: DatePicker,
   decorators: [withCenteredStory],
