@@ -1,4 +1,4 @@
-import { ComponentMeta, ComponentStory } from '@storybook/react';
+import { Meta, StoryFn } from '@storybook/react';
 import React, { useState } from 'react';
 
 import { Button, Drawer, Tab, TabsBar } from '@grafana/ui';
@@ -7,7 +7,7 @@ import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
 
 import mdx from './Drawer.mdx';
 
-const meta: ComponentMeta<typeof Drawer> = {
+const meta: Meta<typeof Drawer> = {
   title: 'Overlays/Drawer',
   component: Drawer,
   decorators: [withCenteredStory],
@@ -32,7 +32,7 @@ const meta: ComponentMeta<typeof Drawer> = {
   },
 };
 
-export const Global: ComponentStory<typeof Drawer> = (args) => {
+export const Global: StoryFn<typeof Drawer> = (args) => {
   const [isOpen, setIsOpen] = useState(false);
   return (
     <>
@@ -60,7 +60,7 @@ Global.args = {
   title: 'Drawer title',
 };
 
-export const LongContent: ComponentStory<typeof Drawer> = (args) => {
+export const LongContent: StoryFn<typeof Drawer> = (args) => {
   const [isOpen, setIsOpen] = useState(false);
   return (
     <>
@@ -141,7 +141,7 @@ LongContent.args = {
   title: 'Drawer title with long content',
 };
 
-export const WithTabs: ComponentStory<typeof Drawer> = (args) => {
+export const WithTabs: StoryFn<typeof Drawer> = (args) => {
   const [isOpen, setIsOpen] = useState(false);
   const [activeTab, setActiveTab] = useState('options');
 
