@@ -4,7 +4,6 @@ import { FocusScope } from '@react-aria/focus';
 import { useOverlay } from '@react-aria/overlays';
 import RcDrawer from 'rc-drawer';
 import React, { ReactNode, useEffect } from 'react';
-import { useClickAway } from 'react-use';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
@@ -73,8 +72,6 @@ export function Drawer({
 
   // Adds body class while open so the toolbar nav can hide some actions while drawer is open
   useBodyClassWhileOpen();
-  // Close when we click outside mask (topnav) but only if closeOnMaskClick is true
-  useClickAway(overlayRef, closeOnMaskClick ? onClose : doNothing);
 
   // Apply size styles (unless deprecated width prop is used)
   const rootClass = cx(styles.drawer, !width && styles.sizes[size]);
@@ -125,7 +122,7 @@ export function Drawer({
                 />
               </div>
               <div className={styles.titleWrapper}>
-                <Text as="h3" {...titleProps}>
+                <Text element="h3" {...titleProps}>
                   {title}
                 </Text>
                 {subtitle && <div className={styles.subtitle}>{subtitle}</div>}
@@ -143,8 +140,6 @@ export function Drawer({
   );
 }
 
-function doNothing() {}
-
 function useBodyClassWhileOpen() {
   useEffect(() => {
     if (!document.body) {
@@ -161,30 +156,35 @@ function useBodyClassWhileOpen() {
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    container: css`
-      display: flex;
-      flex-direction: column;
-      height: 100%;
-      flex: 1 1 0;
-    `,
-    drawer: css`
-      .main-view & {
-        top: 81px;
-      }
+    container: css({
+      display: 'flex',
+      flexDirection: 'column',
+      height: '100%',
+      flex: '1 1 0',
+      minHeight: '100%',
+    }),
+    drawer: css({
+      '.main-view &': {
+        top: 81,
+      },
 
-      .main-view--search-bar-hidden & {
-        top: 41px;
-      }
+      '.main-view--search-bar-hidden &': {
+        top: 41,
+      },
 
-      .rc-drawer-content-wrapper {
-        box-shadow: ${theme.shadows.z3};
+      '.main-view--chrome-hidden &': {
+        top: 0,
+      },
 
-        ${theme.breakpoints.down('sm')} {
-          width: calc(100% - ${theme.spacing(2)}) !important;
-          min-width: 0 !important;
-        }
-      }
-    `,
+      '.rc-drawer-content-wrapper': {
+        boxShadow: theme.shadows.z3,
+
+        [theme.breakpoints.down('sm')]: {
+          width: `calc(100% - ${theme.spacing(2)}) !important`,
+          minWidth: '0 !important',
+        },
+      },
+    }),
     sizes: {
       sm: css({
         '.rc-drawer-content-wrapper': {
@@ -213,38 +213,64 @@ const getStyles = (theme: GrafanaTheme2) => {
         },
       }),
     },
-    drawerContent: css`
-      background-color: ${theme.colors.background.primary} !important;
-      display: flex;
-      flex-direction: column;
-      overflow: hidden;
-      z-index: ${theme.zIndex.dropdown};
-    `,
-    drawerMotion: css`
-      &-appear {
-        transform: translateX(100%);
-        transition: none !important;
+    drawerContent: css({
+      backgroundColor: `${theme.colors.background.primary} !important`,
+      display: 'flex',
+      flexDirection: 'column',
+      overflow: 'hidden',
+      zIndex: theme.zIndex.dropdown,
+    }),
+    drawerMotion: css({
+      '&-appear': {
+        transform: 'translateX(100%)',
+        transition: 'none !important',
 
-        &-active {
-          transition: ${theme.transitions.create('transform')} !important;
-          transform: translateX(0);
-        }
-      }
-    `,
-    mask: css`
-      background-color: ${theme.components.overlay.background} !important;
-      backdrop-filter: blur(1px);
-    `,
-    maskMotion: css`
-      &-appear {
-        opacity: 0;
+        '&-active': {
+          transition: `${theme.transitions.create('transform')} !important`,
+          transform: 'translateX(0)',
+        },
+      },
+    }),
+    // we want the mask itself to span the whole page including the top bar
+    // this ensures trying to click something in the top bar will close the drawer correctly
+    // but we don't want the backdrop styling to apply over the top bar as it looks weird
+    // instead have a child pseudo element to apply the backdrop styling below the top bar
+    mask: css({
+      backgroundColor: 'transparent',
+      position: 'fixed',
 
-        &-active {
-          opacity: 1;
-          transition: ${theme.transitions.create('opacity')};
-        }
-      }
-    `,
+      '&:before': {
+        backgroundColor: `${theme.components.overlay.background} !important`,
+        backdropFilter: 'blur(1px)',
+        bottom: 0,
+        content: '""',
+        left: 0,
+        position: 'fixed',
+        right: 0,
+
+        '.main-view &': {
+          top: 81,
+        },
+
+        '.main-view--search-bar-hidden &': {
+          top: 41,
+        },
+
+        '.main-view--chrome-hidden &': {
+          top: 0,
+        },
+      },
+    }),
+    maskMotion: css({
+      '&-appear': {
+        opacity: 0,
+
+        '&-active': {
+          opacity: 1,
+          transition: theme.transitions.create('opacity'),
+        },
+      },
+    }),
     header: css({
       flexGrow: 0,
       padding: theme.spacing(3, 2),
@@ -258,9 +284,9 @@ const getStyles = (theme: GrafanaTheme2) => {
       right: theme.spacing(1),
       top: theme.spacing(2),
     }),
-    titleWrapper: css`
-      overflow-wrap: break-word;
-    `,
+    titleWrapper: css({
+      overflowWrap: 'break-word',
+    }),
     subtitle: css({
       color: theme.colors.text.secondary,
       paddingTop: theme.spacing(1),
