@@ -135,7 +135,7 @@ export class Graph extends PureComponent<GraphProps, GraphState> {
   renderTooltip = () => {
     const { children, series, timeZone } = this.props;
     const { pos, activeItem, isTooltipVisible } = this.state;
-    let tooltipElement: React.ReactElement<VizTooltipProps> | null = null;
+    let tooltipElement: React.ReactElement<VizTooltipProps> | undefined;
 
     if (!isTooltipVisible || !pos || series.length === 0) {
       return null;
@@ -147,18 +147,17 @@ export class Graph extends PureComponent<GraphProps, GraphState> {
       if (tooltipElement) {
         return;
       }
-      // @ts-ignore
       const childType = c && c.type && (c.type.displayName || c.type.name);
 
       if (childType === VizTooltip.displayName) {
-        tooltipElement = c as React.ReactElement<VizTooltipProps>;
+        tooltipElement = c;
       }
     });
     // If no tooltip provided, skip rendering
     if (!tooltipElement) {
       return null;
     }
-    const tooltipElementProps = (tooltipElement as React.ReactElement<VizTooltipProps>).props;
+    const tooltipElementProps = tooltipElement.props;
 
     const tooltipMode = tooltipElementProps.mode || 'single';
 
@@ -203,7 +202,7 @@ export class Graph extends PureComponent<GraphProps, GraphState> {
 
     const tooltipContent = React.createElement(tooltipContentRenderer, { ...tooltipContentProps });
 
-    return React.cloneElement<VizTooltipProps>(tooltipElement as React.ReactElement<VizTooltipProps>, {
+    return React.cloneElement(tooltipElement, {
       content: tooltipContent,
       position: { x: pos.pageX, y: pos.pageY },
       offset: { x: 10, y: 10 },
