@@ -10,6 +10,7 @@ import {
   Field,
   FieldMatcherID,
   fieldMatchers,
+  FieldType,
   LegacyGraphHoverEvent,
   TimeRange,
   TimeZone,
@@ -54,7 +55,7 @@ export interface GraphNGProps extends Themeable2 {
   children?: (builder: UPlotConfigBuilder, alignedFrame: DataFrame) => React.ReactNode;
   prepConfig: (alignedFrame: DataFrame, allFrames: DataFrame[], getTimeRange: () => TimeRange) => UPlotConfigBuilder;
   propsToDiff?: Array<string | PropDiffFn>;
-  preparePlotFrame?: (frames: DataFrame[], dimFields: XYFieldMatchers) => DataFrame;
+  preparePlotFrame?: (frames: DataFrame[], dimFields: XYFieldMatchers) => DataFrame | null;
   renderLegend: (config: UPlotConfigBuilder) => React.ReactElement | null;
 
   /**
@@ -120,7 +121,7 @@ export class GraphNG extends Component<GraphNGProps, GraphNGState> {
       frames,
       fields || {
         x: fieldMatchers.get(FieldMatcherID.firstTimeField).get({}),
-        y: fieldMatchers.get(FieldMatcherID.numeric).get({}),
+        y: fieldMatchers.get(FieldMatcherID.byTypes).get(new Set([FieldType.number, FieldType.enum])),
       },
       props.timeRange
     );
@@ -248,7 +249,7 @@ export class GraphNG extends Component<GraphNGProps, GraphNGState> {
   }
 
   render() {
-    const { width, height, children, timeRange, renderLegend } = this.props;
+    const { width, height, children, renderLegend } = this.props;
     const { config, alignedFrame, alignedData } = this.state;
 
     if (!config) {
@@ -263,7 +264,6 @@ export class GraphNG extends Component<GraphNGProps, GraphNGState> {
             data={alignedData!}
             width={vizWidth}
             height={vizHeight}
-            timeRange={timeRange}
             plotRef={(u) => ((this.plotInstance as React.MutableRefObject<uPlot>).current = u)}
           >
             {children ? children(config, alignedFrame) : null}
