@@ -107,9 +107,9 @@ WithTabs.args = {
 
 export const UsingContentClassName: Story = ({ title, body, ...args }) => {
   const override = {
-    modalContent: css`
-      background-color: darkorange;
-    `,
+    modalContent: css({
+      backgroundColor: 'darkorange',
+    }),
   };
   return (
     <Modal title={title} {...args} contentClassName={cx(override.modalContent)}>
