@@ -241,13 +241,17 @@ export class UnThemedQueryField extends PureComponent<QueryFieldProps, QueryFiel
 
 export const QueryField = withTheme2(UnThemedQueryField);
 
+// By default QueryField calls onChange if onBlur is not defined, this will trigger a rerender
+// And slate will claim the focus, making it impossible to leave the field.
+QueryField.defaultProps = {
+  onBlur: () => {},
+};
+
 const getStyles = (theme: GrafanaTheme2) => {
   const focusStyles = getFocusStyles(theme);
   return {
-    wrapper: css`
-      &:focus-within {
-        ${focusStyles}
-      }
-    `,
+    wrapper: css({
+      '&:focus-within': focusStyles,
+    }),
   };
 };
