@@ -260,12 +260,13 @@ export const Table = memo((props: Props) => {
               columnIndex={index}
               columnCount={row.cells.length}
               timeRange={timeRange}
+              frame={data}
             />
           ))}
         </div>
       );
     },
-    [onCellFilterAdded, page, enablePagination, prepareRow, rows, tableStyles, renderSubTable, timeRange]
+    [onCellFilterAdded, page, enablePagination, prepareRow, rows, tableStyles, renderSubTable, timeRange, data]
   );
 
   const onNavigate = useCallback(
