@@ -23,13 +23,13 @@ const getTextAreaStyle = stylesFactory((theme: GrafanaTheme2, invalid = false) =
     textarea: cx(
       sharedInputStyle(theme),
       getFocusStyle(theme),
-      css`
-        display: block;
-        border-radius: ${theme.shape.borderRadius()};
-        padding: ${theme.spacing.gridSize / 4}px ${theme.spacing.gridSize}px;
-        width: 100%;
-        border-color: ${invalid ? theme.colors.error.border : theme.components.input.borderColor};
-      `
+      css({
+        display: 'block',
+        borderRadius: theme.shape.borderRadius(),
+        padding: `${theme.spacing.gridSize / 4}px ${theme.spacing.gridSize}px`,
+        width: '100%',
+        borderColor: invalid ? theme.colors.error.border : theme.components.input.borderColor,
+      })
     ),
   };
 });
