@@ -1,5 +1,5 @@
 import { action } from '@storybook/addon-actions';
-import { ComponentMeta, ComponentStory } from '@storybook/react';
+import { Meta, StoryFn } from '@storybook/react';
 import React from 'react';
 
 import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
@@ -7,7 +7,7 @@ import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
 import { UnitPicker, UnitPickerProps } from './UnitPicker';
 import mdx from './UnitPicker.mdx';
 
-const meta: ComponentMeta<typeof UnitPicker> = {
+const meta: Meta<typeof UnitPicker> = {
   title: 'Pickers and Editors/UnitPicker',
   component: UnitPicker,
   decorators: [withCenteredStory],
@@ -19,7 +19,7 @@ const meta: ComponentMeta<typeof UnitPicker> = {
   },
 };
 
-export const Basic: ComponentStory<typeof UnitPicker> = (args: UnitPickerProps) => <UnitPicker {...args} />;
+export const Basic: StoryFn<typeof UnitPicker> = (args: UnitPickerProps) => <UnitPicker {...args} />;
 
 Basic.args = {
   onChange: action('onChange fired'),
