@@ -9,13 +9,13 @@ export interface Props {
 
 export const DashboardStoryCanvas = ({ children }: Props) => {
   const theme = useTheme2();
-  const style = css`
-    width: 100%;
-    height: 100%;
-    padding: 32px;
-    background: ${theme.colors.background.canvas};
-    overflow: auto;
-  `;
+  const style = css({
+    width: '100%',
+    height: '100%',
+    padding: '32px',
+    background: theme.colors.background.canvas,
+    overflow: 'auto',
+  });
 
   return <div className={style}>{children}</div>;
 };
