@@ -18,12 +18,10 @@ import (
 
 	"github.com/ProtonMail/go-crypto/openpgp"
 	"github.com/ProtonMail/go-crypto/openpgp/clearsign"
-	openpgpErrors "github.com/ProtonMail/go-crypto/openpgp/errors"
 	"github.com/ProtonMail/go-crypto/openpgp/packet"
 	"github.com/gobwas/glob"
 
 	"github.com/grafana/grafana/pkg/plugins"
-	"github.com/grafana/grafana/pkg/plugins/config"
 	"github.com/grafana/grafana/pkg/plugins/log"
 	"github.com/grafana/grafana/pkg/setting"
 )
@@ -65,10 +63,10 @@ type Signature struct {
 
 var _ plugins.SignatureCalculator = &Signature{}
 
-func ProvideService(cfg *config.Cfg, kr plugins.KeyRetriever) *Signature {
+func ProvideService(kr plugins.KeyRetriever) *Signature {
 	return &Signature{
-		log: log.New("plugin.signature"),
 		kr:  kr,
+		log: log.New("plugin.signature"),
 	}
 }
 
@@ -105,7 +103,7 @@ func (s *Signature) Calculate(ctx context.Context, src plugins.PluginSource, plu
 	if len(fsFiles) == 0 {
 		s.log.Warn("No plugin file information in directory", "pluginID", plugin.JSONData.ID)
 		return plugins.Signature{
-			Status: plugins.SignatureInvalid,
+			Status: plugins.SignatureStatusInvalid,
 		}, nil
 	}
 
@@ -114,13 +112,13 @@ func (s *Signature) Calculate(ctx context.Context, src plugins.PluginSource, plu
 		if errors.Is(err, plugins.ErrFileNotExist) {
 			s.log.Debug("Could not find a MANIFEST.txt", "id", plugin.JSONData.ID, "err", err)
 			return plugins.Signature{
-				Status: plugins.SignatureUnsigned,
+				Status: plugins.SignatureStatusUnsigned,
 			}, nil
 		}
 
 		s.log.Debug("Could not open MANIFEST.txt", "id", plugin.JSONData.ID, "err", err)
 		return plugins.Signature{
-			Status: plugins.SignatureInvalid,
+			Status: plugins.SignatureStatusInvalid,
 		}, nil
 	}
 	defer func() {
@@ -136,7 +134,7 @@ func (s *Signature) Calculate(ctx context.Context, src plugins.PluginSource, plu
 	if err != nil || len(byteValue) < 10 {
 		s.log.Debug("MANIFEST.TXT is invalid", "id", plugin.JSONData.ID)
 		return plugins.Signature{
-			Status: plugins.SignatureUnsigned,
+			Status: plugins.SignatureStatusUnsigned,
 		}, nil
 	}
 
@@ -144,20 +142,20 @@ func (s *Signature) Calculate(ctx context.Context, src plugins.PluginSource, plu
 	if err != nil {
 		s.log.Warn("Plugin signature invalid", "id", plugin.JSONData.ID, "err", err)
 		return plugins.Signature{
-			Status: plugins.SignatureInvalid,
+			Status: plugins.SignatureStatusInvalid,
 		}, nil
 	}
 
 	if !manifest.isV2() {
 		return plugins.Signature{
-			Status: plugins.SignatureInvalid,
+			Status: plugins.SignatureStatusInvalid,
 		}, nil
 	}
 
 	// Make sure the versions all match
 	if manifest.Plugin != plugin.JSONData.ID || manifest.Version != plugin.JSONData.Info.Version {
 		return plugins.Signature{
-			Status: plugins.SignatureModified,
+			Status: plugins.SignatureStatusModified,
 		}, nil
 	}
 
@@ -170,7 +168,7 @@ func (s *Signature) Calculate(ctx context.Context, src plugins.PluginSource, plu
 			s.log.Warn("Could not find root URL that matches running application URL", "plugin", plugin.JSONData.ID,
 				"appUrl", setting.AppUrl, "rootUrls", manifest.RootURLs)
 			return plugins.Signature{
-				Status: plugins.SignatureInvalid,
+				Status: plugins.SignatureStatusInvalid,
 			}, nil
 		}
 	}
@@ -182,7 +180,7 @@ func (s *Signature) Calculate(ctx context.Context, src plugins.PluginSource, plu
 		err = verifyHash(s.log, plugin, p, hash)
 		if err != nil {
 			return plugins.Signature{
-				Status: plugins.SignatureModified,
+				Status: plugins.SignatureStatusModified,
 			}, nil
 		}
 
@@ -196,7 +194,7 @@ func (s *Signature) Calculate(ctx context.Context, src plugins.PluginSource, plu
 		f = toSlash(f)
 
 		// Ignoring unsigned Chromium debug.log so it doesn't invalidate the signature for Renderer plugin running on Windows
-		if runningWindows && plugin.JSONData.Type == plugins.Renderer && f == "chrome-win/debug.log" {
+		if runningWindows && plugin.JSONData.Type == plugins.TypeRenderer && f == "chrome-win/debug.log" {
 			continue
 		}
 
@@ -211,13 +209,13 @@ func (s *Signature) Calculate(ctx context.Context, src plugins.PluginSource, plu
 	if len(unsignedFiles) > 0 {
 		s.log.Warn("The following files were not included in the signature", "plugin", plugin.JSONData.ID, "files", unsignedFiles)
 		return plugins.Signature{
-			Status: plugins.SignatureModified,
+			Status: plugins.SignatureStatusModified,
 		}, nil
 	}
 
 	s.log.Debug("Plugin signature valid", "id", plugin.JSONData.ID)
 	return plugins.Signature{
-		Status:     plugins.SignatureValid,
+		Status:     plugins.SignatureStatusValid,
 		Type:       manifest.SignatureType,
 		SigningOrg: manifest.SignedByOrgName,
 	}, nil
@@ -274,7 +272,7 @@ func urlMatch(specs []string, target string, signatureType plugins.SignatureType
 			return true, nil
 		}
 
-		if signatureType != plugins.PrivateGlobSignature {
+		if signatureType != plugins.SignatureTypePrivateGlob {
 			continue
 		}
 
@@ -342,11 +340,7 @@ func (s *Signature) Verify(ctx context.Context, keyID string, block *clearsign.B
 	if _, err = openpgp.CheckDetachedSignature(keyring,
 		bytes.NewBuffer(block.Bytes),
 		block.ArmoredSignature.Body, &packet.Config{}); err != nil {
-		// If the key includes revocations, we can assume that the key was revoked
-		if len(keyring) > 0 && len(keyring[0].Revocations) > 0 {
-			return fmt.Errorf("%s (KeyID: %s): %w", openpgpErrors.ErrKeyRevoked.Error(), keyID, err)
-		}
-		return fmt.Errorf("%v: %w", "failed to check signature", err)
+		return fmt.Errorf("failed to check signature: %w", err)
 	}
 
 	return nil
