@@ -6,17 +6,20 @@ import (
 	"fmt"
 	"time"
 
-	"github.com/grafana/grafana/pkg/bus"
 	"github.com/grafana/grafana/pkg/components/imguploader"
 	"github.com/grafana/grafana/pkg/infra/log"
 	"github.com/grafana/grafana/pkg/infra/metrics"
 	"github.com/grafana/grafana/pkg/models"
+	alertmodels "github.com/grafana/grafana/pkg/services/alerting/models"
+	"github.com/grafana/grafana/pkg/services/notifications"
+	"github.com/grafana/grafana/pkg/services/org"
 	"github.com/grafana/grafana/pkg/services/rendering"
 	"github.com/grafana/grafana/pkg/setting"
 )
 
 // for stubbing in tests
-//nolint: gocritic
+//
+//nolint:gocritic
 var newImageUploaderProvider = func() (imguploader.ImageUploader, error) {
 	return imguploader.NewImageUploader()
 }
@@ -45,6 +48,7 @@ type NotifierOption struct {
 	Required       bool           `json:"required"`
 	ValidationRule string         `json:"validationRule"`
 	Secure         bool           `json:"secure"`
+	DependsOn      string         `json:"dependsOn"`
 }
 
 // InputType is the type of input that can be rendered in the frontend.
@@ -53,7 +57,7 @@ type InputType string
 const (
 	// InputTypeText will render a text field in the frontend
 	InputTypeText = "text"
-	// InputTypePassword will render a text field in the frontend
+	// InputTypePassword will render a password field in the frontend
 	InputTypePassword = "password"
 )
 
@@ -83,16 +87,22 @@ type ShowWhen struct {
 	Is    string `json:"is"`
 }
 
-func newNotificationService(renderService rendering.Service) *notificationService {
+func newNotificationService(renderService rendering.Service, sqlStore AlertStore, notificationSvc *notifications.NotificationService, decryptFn GetDecryptedValueFn) *notificationService {
 	return &notificationService{
-		log:           log.New("alerting.notifier"),
-		renderService: renderService,
+		log:                 log.New("alerting.notifier"),
+		renderService:       renderService,
+		sqlStore:            sqlStore,
+		notificationService: notificationSvc,
+		decryptFn:           decryptFn,
 	}
 }
 
 type notificationService struct {
-	log           log.Logger
-	renderService rendering.Service
+	log                 log.Logger
+	renderService       rendering.Service
+	sqlStore            AlertStore
+	notificationService *notifications.NotificationService
+	decryptFn           GetDecryptedValueFn
 }
 
 func (n *notificationService) SendIfNeeded(evalCtx *EvalContext) error {
@@ -145,25 +155,25 @@ func (n *notificationService) sendAndMarkAsComplete(evalContext *EvalContext, no
 		return nil
 	}
 
-	cmd := &models.SetAlertNotificationStateToCompleteCommand{
-		Id:      notifierState.state.Id,
+	cmd := &alertmodels.SetAlertNotificationStateToCompleteCommand{
+		ID:      notifierState.state.ID,
 		Version: notifierState.state.Version,
 	}
 
-	return bus.DispatchCtx(evalContext.Ctx, cmd)
+	return n.sqlStore.SetAlertNotificationStateToCompleteCommand(evalContext.Ctx, cmd)
 }
 
 func (n *notificationService) sendNotification(evalContext *EvalContext, notifierState *notifierState) error {
 	if !evalContext.IsTestRun {
-		setPendingCmd := &models.SetAlertNotificationStateToPendingCommand{
-			Id:                           notifierState.state.Id,
+		setPendingCmd := &alertmodels.SetAlertNotificationStateToPendingCommand{
+			ID:                           notifierState.state.ID,
 			Version:                      notifierState.state.Version,
 			AlertRuleStateUpdatedVersion: evalContext.Rule.StateChanges,
 		}
 
-		err := bus.DispatchCtx(evalContext.Ctx, setPendingCmd)
+		err := n.sqlStore.SetAlertNotificationStateToPendingCommand(evalContext.Ctx, setPendingCmd)
 		if err != nil {
-			if errors.Is(err, models.ErrAlertNotificationStateVersionConflict) {
+			if errors.Is(err, alertmodels.ErrAlertNotificationStateVersionConflict) {
 				return nil
 			}
 
@@ -198,12 +208,17 @@ func (n *notificationService) renderAndUploadImage(evalCtx *EvalContext, timeout
 	}
 
 	renderOpts := rendering.Opts{
+		TimeoutOpts: rendering.TimeoutOpts{
+			Timeout: timeout,
+		},
+		AuthOpts: rendering.AuthOpts{
+			OrgID:   evalCtx.Rule.OrgID,
+			OrgRole: org.RoleAdmin,
+		},
 		Width:           1000,
 		Height:          500,
-		Timeout:         timeout,
-		OrgId:           evalCtx.Rule.OrgID,
-		OrgRole:         models.ROLE_ADMIN,
 		ConcurrentLimit: setting.AlertingRenderLimit,
+		Theme:           models.ThemeDark,
 	}
 
 	ref, err := evalCtx.GetDashboardUID()
@@ -211,11 +226,11 @@ func (n *notificationService) renderAndUploadImage(evalCtx *EvalContext, timeout
 		return err
 	}
 
-	renderOpts.Path = fmt.Sprintf("d-solo/%s/%s?orgId=%d&panelId=%d", ref.Uid, ref.Slug, evalCtx.Rule.OrgID, evalCtx.Rule.PanelID)
+	renderOpts.Path = fmt.Sprintf("d-solo/%s/%s?orgId=%d&panelId=%d", ref.UID, ref.Slug, evalCtx.Rule.OrgID, evalCtx.Rule.PanelID)
 
 	n.log.Debug("Rendering alert panel image", "ruleId", evalCtx.Rule.ID, "urlPath", renderOpts.Path)
 	start := time.Now()
-	result, err := n.renderService.Render(evalCtx.Ctx, renderOpts)
+	result, err := n.renderService.Render(evalCtx.Ctx, renderOpts, nil)
 	if err != nil {
 		return err
 	}
@@ -242,36 +257,37 @@ func (n *notificationService) renderAndUploadImage(evalCtx *EvalContext, timeout
 }
 
 func (n *notificationService) getNeededNotifiers(orgID int64, notificationUids []string, evalContext *EvalContext) (notifierStateSlice, error) {
-	query := &models.GetAlertNotificationsWithUidToSendQuery{OrgId: orgID, Uids: notificationUids}
+	query := &alertmodels.GetAlertNotificationsWithUidToSendQuery{OrgID: orgID, UIDs: notificationUids}
 
-	if err := bus.Dispatch(query); err != nil {
+	res, err := n.sqlStore.GetAlertNotificationsWithUidToSend(evalContext.Ctx, query)
+	if err != nil {
 		return nil, err
 	}
 
 	var result notifierStateSlice
-	for _, notification := range query.Result {
-		not, err := InitNotifier(notification)
+	for _, notification := range res {
+		not, err := InitNotifier(notification, n.decryptFn, n.notificationService)
 		if err != nil {
-			n.log.Error("Could not create notifier", "notifier", notification.Uid, "error", err)
+			n.log.Error("Could not create notifier", "notifier", notification.UID, "error", err)
 			continue
 		}
 
-		query := &models.GetOrCreateNotificationStateQuery{
-			NotifierId: notification.Id,
-			AlertId:    evalContext.Rule.ID,
-			OrgId:      evalContext.Rule.OrgID,
+		query := &alertmodels.GetOrCreateNotificationStateQuery{
+			NotifierID: notification.ID,
+			AlertID:    evalContext.Rule.ID,
+			OrgID:      evalContext.Rule.OrgID,
 		}
 
-		err = bus.DispatchCtx(evalContext.Ctx, query)
+		state, err := n.sqlStore.GetOrCreateAlertNotificationState(evalContext.Ctx, query)
 		if err != nil {
-			n.log.Error("Could not get notification state.", "notifier", notification.Id, "error", err)
+			n.log.Error("Could not get notification state.", "notifier", notification.ID, "error", err)
 			continue
 		}
 
-		if not.ShouldNotify(evalContext.Ctx, evalContext, query.Result) {
+		if not.ShouldNotify(evalContext.Ctx, evalContext, state) {
 			result = append(result, &notifierState{
 				notifier: not,
-				state:    query.Result,
+				state:    state,
 			})
 		}
 	}
@@ -280,21 +296,25 @@ func (n *notificationService) getNeededNotifiers(orgID int64, notificationUids [
 }
 
 // InitNotifier instantiate a new notifier based on the model.
-func InitNotifier(model *models.AlertNotification) (Notifier, error) {
+func InitNotifier(model *alertmodels.AlertNotification, fn GetDecryptedValueFn, notificationService *notifications.NotificationService) (Notifier, error) {
 	notifierPlugin, found := notifierFactories[model.Type]
 	if !found {
 		return nil, fmt.Errorf("unsupported notification type %q", model.Type)
 	}
 
-	return notifierPlugin.Factory(model)
+	return notifierPlugin.Factory(model, fn, notificationService)
 }
 
+// GetDecryptedValueFn is a function that returns the decrypted value of
+// the given key. If the key is not present, then it returns the fallback value.
+type GetDecryptedValueFn func(ctx context.Context, sjd map[string][]byte, key string, fallback string, secret string) string
+
 // NotifierFactory is a signature for creating notifiers.
-type NotifierFactory func(notification *models.AlertNotification) (Notifier, error)
+type NotifierFactory func(*alertmodels.AlertNotification, GetDecryptedValueFn, notifications.Service) (Notifier, error)
 
 var notifierFactories = make(map[string]*NotifierPlugin)
 
-// RegisterNotifier register an notifier
+// RegisterNotifier registers a notifier.
 func RegisterNotifier(plugin *NotifierPlugin) {
 	notifierFactories[plugin.Type] = plugin
 }
