@@ -2,15 +2,14 @@ package notifiers
 
 import (
 	"encoding/json"
+	"fmt"
 	"strconv"
 	"strings"
 
-	"fmt"
-
-	"github.com/grafana/grafana/pkg/bus"
 	"github.com/grafana/grafana/pkg/infra/log"
-	"github.com/grafana/grafana/pkg/models"
 	"github.com/grafana/grafana/pkg/services/alerting"
+	"github.com/grafana/grafana/pkg/services/alerting/models"
+	"github.com/grafana/grafana/pkg/services/notifications"
 )
 
 func init() {
@@ -20,25 +19,6 @@ func init() {
 		Description: "Sends notifications uto a HipChat Room",
 		Heading:     "HipChat settings",
 		Factory:     NewHipChatNotifier,
-		OptionsTemplate: `
-      <h3 class="page-heading">HipChat settings</h3>
-			      <div class="gf-form max-width-30">
-			        <span class="gf-form-label width-8">Hip Chat Url</span>
-			        <input type="text" required class="gf-form-input max-width-30" ng-model="ctrl.model.settings.url" placeholder="HipChat URL (ex https://grafana.hipchat.com)"></input>
-			      </div>
-      <div class="gf-form max-width-30">
-        <span class="gf-form-label width-8">API Key</span>
-        <input type="text" required class="gf-form-input max-width-30" ng-model="ctrl.model.settings.apikey" placeholder="HipChat API Key"></input>
-      </div>
-      <div class="gf-form max-width-30">
-        <span class="gf-form-label width-8">Room ID</span>
-        <input type="text"
-          class="gf-form-input max-width-30"
-          ng-model="ctrl.model.settings.roomid"
-          data-placement="right">
-        </input>
-      </div>
-    `,
 		Options: []alerting.NotifierOption{
 			{
 				Label:        "Hip Chat Url",
@@ -64,7 +44,6 @@ func init() {
 			},
 		},
 	})
-
 }
 
 const (
@@ -73,11 +52,9 @@ const (
 
 // NewHipChatNotifier is the constructor functions
 // for the HipChatNotifier
-func NewHipChatNotifier(model *models.AlertNotification) (alerting.Notifier, error) {
+func NewHipChatNotifier(model *models.AlertNotification, _ alerting.GetDecryptedValueFn, ns notifications.Service) (alerting.Notifier, error) {
 	url := model.Settings.Get("url").MustString()
-	if strings.HasSuffix(url, "/") {
-		url = url[:len(url)-1]
-	}
+	url = strings.TrimSuffix(url, "/")
 	if url == "" {
 		return nil, alerting.ValidationError{Reason: "Could not find url property in settings"}
 	}
@@ -86,7 +63,7 @@ func NewHipChatNotifier(model *models.AlertNotification) (alerting.Notifier, err
 	roomID := model.Settings.Get("roomid").MustString()
 
 	return &HipChatNotifier{
-		NotifierBase: NewNotifierBase(model),
+		NotifierBase: NewNotifierBase(model, ns),
 		URL:          url,
 		APIKey:       apikey,
 		RoomID:       roomID,
@@ -141,7 +118,7 @@ func (hc *HipChatNotifier) Notify(evalContext *alerting.EvalContext) error {
 	}
 
 	message := ""
-	if evalContext.Rule.State != models.AlertStateOK { //don't add message when going back to alert state ok.
+	if evalContext.Rule.State != models.AlertStateOK { // don't add message when going back to alert state ok.
 		message += " " + evalContext.Rule.Message
 	}
 
@@ -149,7 +126,7 @@ func (hc *HipChatNotifier) Notify(evalContext *alerting.EvalContext) error {
 		message = evalContext.GetNotificationTitle() + " in state " + evalContext.GetStateModel().Text
 	}
 
-	//HipChat has a set list of colors
+	// HipChat has a set list of colors
 	var color string
 	switch evalContext.Rule.State {
 	case models.AlertStateOK:
@@ -158,6 +135,8 @@ func (hc *HipChatNotifier) Notify(evalContext *alerting.EvalContext) error {
 		color = "gray"
 	case models.AlertStateAlerting:
 		color = "red"
+	default:
+		// Handle other cases?
 	}
 
 	// Add a card with link to the dashboard
@@ -168,7 +147,7 @@ func (hc *HipChatNotifier) Notify(evalContext *alerting.EvalContext) error {
 		"title":       evalContext.GetNotificationTitle(),
 		"description": message,
 		"icon": map[string]interface{}{
-			"url": "https://grafana.com/assets/img/fav32.png",
+			"url": "https://grafana.com/static/assets/img/fav32.png",
 		},
 		"date":       evalContext.EndTime.Unix(),
 		"attributes": attributes,
@@ -193,9 +172,9 @@ func (hc *HipChatNotifier) Notify(evalContext *alerting.EvalContext) error {
 	hipURL := fmt.Sprintf("%s/v2/room/%s/notification?auth_token=%s", hc.URL, hc.RoomID, hc.APIKey)
 	data, _ := json.Marshal(&body)
 	hc.log.Info("Request payload", "json", string(data))
-	cmd := &models.SendWebhookSync{Url: hipURL, Body: string(data)}
+	cmd := &notifications.SendWebhookSync{Url: hipURL, Body: string(data)}
 
-	if err := bus.DispatchCtx(evalContext.Ctx, cmd); err != nil {
+	if err := hc.NotificationService.SendWebhookSync(evalContext.Ctx, cmd); err != nil {
 		hc.log.Error("Failed to send hipchat notification", "error", err, "webhook", hc.Name)
 		return err
 	}
