@@ -1,15 +1,30 @@
 package alerting
 
 import (
+	"context"
 	"errors"
 	"fmt"
+	"reflect"
 	"regexp"
 	"strconv"
 	"time"
 
-	"github.com/grafana/grafana/pkg/bus"
 	"github.com/grafana/grafana/pkg/components/simplejson"
-	"github.com/grafana/grafana/pkg/models"
+	"github.com/grafana/grafana/pkg/services/alerting/models"
+	"github.com/grafana/grafana/pkg/services/tag"
+)
+
+var unitMultiplier = map[string]int{
+	"s": 1,
+	"m": 60,
+	"h": 3600,
+	"d": 86400,
+}
+
+var (
+	valueFormatRegex = regexp.MustCompile(`^\d+`)
+	isDigitRegex     = regexp.MustCompile(`^[0-9]+$`)
+	unitFormatRegex  = regexp.MustCompile(`[a-z]+`)
 )
 
 var (
@@ -18,6 +33,9 @@ var (
 
 	// ErrFrequencyCouldNotBeParsed frequency cannot be parsed
 	ErrFrequencyCouldNotBeParsed = errors.New(`"evaluate every" field could not be parsed`)
+
+	// ErrWrongUnitFormat wrong unit format
+	ErrWrongUnitFormat = fmt.Errorf(`time unit not supported. supported units: %s`, reflect.ValueOf(unitMultiplier).MapKeys())
 )
 
 // Rule is the in-memory version of an alert rule.
@@ -36,7 +54,7 @@ type Rule struct {
 	State               models.AlertStateType
 	Conditions          []Condition
 	Notifications       []string
-	AlertRuleTags       []*models.Tag
+	AlertRuleTags       []*tag.Tag
 
 	StateChanges int64
 }
@@ -66,30 +84,28 @@ func (e ValidationError) Error() string {
 	}
 
 	if e.Err != nil {
-		return fmt.Sprintf("Alert validation error: %s%s", e.Err.Error(), extraInfo)
+		return fmt.Sprintf("alert validation error: %s%s", e.Err.Error(), extraInfo)
 	}
 
-	return fmt.Sprintf("Alert validation error: %s", extraInfo)
-}
-
-var (
-	valueFormatRegex = regexp.MustCompile(`^\d+`)
-	unitFormatRegex  = regexp.MustCompile(`\w{1}$`)
-)
-
-var unitMultiplier = map[string]int{
-	"s": 1,
-	"m": 60,
-	"h": 3600,
-	"d": 86400,
+	return fmt.Sprintf("alert validation error: %s", extraInfo)
 }
 
 func getTimeDurationStringToSeconds(str string) (int64, error) {
-	multiplier := 1
+	// Check if frequency lacks unit
+	if isDigitRegex.MatchString(str) || str == "" {
+		return 0, ErrFrequencyCouldNotBeParsed
+	}
+
+	unit := unitFormatRegex.FindAllString(str, 1)[0]
+	if _, ok := unitMultiplier[unit]; !ok {
+		return 0, ErrWrongUnitFormat
+	}
+
+	multiplier := unitMultiplier[unit]
 
 	matches := valueFormatRegex.FindAllString(str, 1)
 
-	if len(matches) <= 0 {
+	if len(matches) == 0 {
 		return 0, ErrFrequencyCouldNotBeParsed
 	}
 
@@ -102,23 +118,39 @@ func getTimeDurationStringToSeconds(str string) (int64, error) {
 		return 0, ErrFrequencyCannotBeZeroOrLess
 	}
 
-	unit := unitFormatRegex.FindAllString(str, 1)[0]
-
-	if val, ok := unitMultiplier[unit]; ok {
-		multiplier = val
-	}
-
 	return int64(value * multiplier), nil
 }
 
+func getForValue(rawFor string) (time.Duration, error) {
+	var forValue time.Duration
+	var err error
+
+	if rawFor != "" {
+		if rawFor != "0" {
+			strings := unitFormatRegex.FindAllString(rawFor, 1)
+			if strings == nil {
+				return 0, ValidationError{Reason: fmt.Sprintf("no specified unit, error: %s", ErrWrongUnitFormat.Error())}
+			}
+			if _, ok := unitMultiplier[strings[0]]; !ok {
+				return 0, ValidationError{Reason: fmt.Sprintf("could not parse for field, error: %s", ErrWrongUnitFormat.Error())}
+			}
+		}
+		forValue, err = time.ParseDuration(rawFor)
+		if err != nil {
+			return 0, ValidationError{Reason: "Could not parse for field"}
+		}
+	}
+	return forValue, nil
+}
+
 // NewRuleFromDBAlert maps a db version of
 // alert to an in-memory version.
-func NewRuleFromDBAlert(ruleDef *models.Alert) (*Rule, error) {
+func NewRuleFromDBAlert(ctx context.Context, store AlertStore, ruleDef *models.Alert, logTranslationFailures bool) (*Rule, error) {
 	model := &Rule{}
-	model.ID = ruleDef.Id
-	model.OrgID = ruleDef.OrgId
-	model.DashboardID = ruleDef.DashboardId
-	model.PanelID = ruleDef.PanelId
+	model.ID = ruleDef.ID
+	model.OrgID = ruleDef.OrgID
+	model.DashboardID = ruleDef.DashboardID
+	model.PanelID = ruleDef.PanelID
 	model.Name = ruleDef.Name
 	model.Message = ruleDef.Message
 	model.State = ruleDef.State
@@ -138,9 +170,15 @@ func NewRuleFromDBAlert(ruleDef *models.Alert) (*Rule, error) {
 	for _, v := range ruleDef.Settings.Get("notifications").MustArray() {
 		jsonModel := simplejson.NewFromAny(v)
 		if id, err := jsonModel.Get("id").Int64(); err == nil {
-			uid, err := translateNotificationIDToUID(id, ruleDef.OrgId)
+			uid, err := translateNotificationIDToUID(ctx, store, id, ruleDef.OrgID)
 			if err != nil {
-				logger.Error("Unable to translate notification id to uid", "error", err.Error(), "dashboardId", model.DashboardID, "alertId", model.ID, "panelId", model.PanelID, "notificationId", id)
+				if !errors.Is(err, models.ErrAlertNotificationFailedTranslateUniqueID) {
+					logger.Error("Failed to translate notification id to uid", "error", err.Error(), "dashboardId", model.DashboardID, "alert", model.Name, "panelId", model.PanelID, "notificationId", id)
+				}
+
+				if logTranslationFailures {
+					logger.Warn("Unable to translate notification id to uid", "dashboardId", model.DashboardID, "alert", model.Name, "panelId", model.PanelID, "notificationId", id)
+				}
 			} else {
 				model.Notifications = append(model.Notifications, uid)
 			}
@@ -173,27 +211,27 @@ func NewRuleFromDBAlert(ruleDef *models.Alert) (*Rule, error) {
 	return model, nil
 }
 
-func translateNotificationIDToUID(id int64, orgID int64) (string, error) {
-	notificationUID, err := getAlertNotificationUIDByIDAndOrgID(id, orgID)
+func translateNotificationIDToUID(ctx context.Context, store AlertStore, id int64, orgID int64) (string, error) {
+	notificationUID, err := getAlertNotificationUIDByIDAndOrgID(ctx, store, id, orgID)
 	if err != nil {
-		logger.Debug("Failed to translate Notification Id to Uid", "orgID", orgID, "Id", id)
 		return "", err
 	}
 
 	return notificationUID, nil
 }
 
-func getAlertNotificationUIDByIDAndOrgID(notificationID int64, orgID int64) (string, error) {
+func getAlertNotificationUIDByIDAndOrgID(ctx context.Context, store AlertStore, notificationID int64, orgID int64) (string, error) {
 	query := &models.GetAlertNotificationUidQuery{
-		OrgId: orgID,
-		Id:    notificationID,
+		OrgID: orgID,
+		ID:    notificationID,
 	}
 
-	if err := bus.Dispatch(query); err != nil {
+	uid, err := store.GetAlertNotificationUidWithId(ctx, query)
+	if err != nil {
 		return "", err
 	}
 
-	return query.Result, nil
+	return uid, nil
 }
 
 // ConditionFactory is the function signature for creating `Conditions`.
