@@ -3,14 +3,14 @@ package alerting
 import (
 	"context"
 	"fmt"
+	"math/rand"
+	"net/http"
 
-	"github.com/grafana/grafana/pkg/components/securejsondata"
-
-	"github.com/grafana/grafana/pkg/bus"
 	"github.com/grafana/grafana/pkg/components/null"
 	"github.com/grafana/grafana/pkg/components/simplejson"
 	"github.com/grafana/grafana/pkg/infra/log"
-	"github.com/grafana/grafana/pkg/models"
+	"github.com/grafana/grafana/pkg/services/alerting/models"
+	"github.com/grafana/grafana/pkg/services/annotations/annotationstest"
 )
 
 // NotificationTestCommand initiates an test
@@ -29,49 +29,23 @@ var (
 	logger = log.New("alerting.testnotification")
 )
 
-func init() {
-	bus.AddHandler("alerting", handleNotificationTestCommand)
-}
+func (s *AlertNotificationService) HandleNotificationTestCommand(ctx context.Context, cmd *NotificationTestCommand) error {
+	notificationSvc := newNotificationService(nil, nil, nil, nil)
 
-func handleNotificationTestCommand(cmd *NotificationTestCommand) error {
-	notifier := newNotificationService(nil)
-
-	model := &models.AlertNotification{
+	model := models.AlertNotification{
+		ID:       cmd.ID,
+		OrgID:    cmd.OrgID,
 		Name:     cmd.Name,
 		Type:     cmd.Type,
 		Settings: cmd.Settings,
 	}
 
-	secureSettingsMap := map[string]string{}
-
-	if cmd.ID > 0 {
-		query := &models.GetAlertNotificationsQuery{
-			OrgId: cmd.OrgID,
-			Id:    cmd.ID,
-		}
-		if err := bus.Dispatch(query); err != nil {
-			return err
-		}
-
-		if query.Result.SecureSettings != nil {
-			secureSettingsMap = query.Result.SecureSettings.Decrypt()
-		}
-	}
-
-	for k, v := range cmd.SecureSettings {
-		secureSettingsMap[k] = v
-	}
-
-	model.SecureSettings = securejsondata.GetEncryptedJsonData(secureSettingsMap)
-
-	notifiers, err := InitNotifier(model)
-
+	notifier, err := s.createNotifier(ctx, &model, cmd.SecureSettings)
 	if err != nil {
-		logger.Error("Failed to create notifier", "error", err.Error())
 		return err
 	}
 
-	return notifier.sendNotifications(createTestEvalContext(cmd), notifierStateSlice{{notifier: notifiers}})
+	return notificationSvc.sendNotifications(createTestEvalContext(cmd), notifierStateSlice{{notifier: notifier}})
 }
 
 func createTestEvalContext(cmd *NotificationTestCommand) *EvalContext {
@@ -81,15 +55,16 @@ func createTestEvalContext(cmd *NotificationTestCommand) *EvalContext {
 		Name:        "Test notification",
 		Message:     "Someone is testing the alert notification within Grafana.",
 		State:       models.AlertStateAlerting,
+		ID:          rand.Int63(),
 	}
 
-	ctx := NewEvalContext(context.Background(), testRule)
+	ctx := NewEvalContext(context.Background(), testRule, fakeRequestValidator{}, nil, nil, nil, annotationstest.NewFakeAnnotationsRepo())
 	if cmd.Settings.Get("uploadImage").MustBool(true) {
-		ctx.ImagePublicURL = "https://grafana.com/assets/img/blog/mixed_styles.png"
+		ctx.ImagePublicURL = "https://grafana.com/static/assets/img/blog/mixed_styles.png"
 	}
 	ctx.IsTestRun = true
 	ctx.Firing = true
-	ctx.Error = fmt.Errorf("This is only a test")
+	ctx.Error = fmt.Errorf("this is only a test")
 	ctx.EvalMatches = evalMatchesBasedOnState()
 
 	return ctx
@@ -109,3 +84,9 @@ func evalMatchesBasedOnState() []*EvalMatch {
 
 	return matches
 }
+
+type fakeRequestValidator struct{}
+
+func (fakeRequestValidator) Validate(_ string, _ *http.Request) error {
+	return nil
+}
