@@ -35,19 +35,19 @@ func TestAuthenticateJWT(t *testing.T) {
 	}
 	jwtHeaderName := "X-Forwarded-User"
 	wantID := &authn.Identity{
-		OrgID:          0,
-		OrgCount:       0,
-		OrgName:        "",
-		OrgRoles:       map[int64]roletype.RoleType{1: roletype.RoleAdmin},
-		ID:             "",
-		Login:          "eai-doe",
-		Name:           "Eai Doe",
-		Email:          "eai.doe@cor.po",
-		IsGrafanaAdmin: boolPtr(false),
-		AuthModule:     "jwt",
-		AuthID:         "1234567890",
-		IsDisabled:     false,
-		HelpFlags1:     0,
+		OrgID:           0,
+		OrgCount:        0,
+		OrgName:         "",
+		OrgRoles:        map[int64]roletype.RoleType{1: roletype.RoleAdmin},
+		ID:              "",
+		Login:           "eai-doe",
+		Name:            "Eai Doe",
+		Email:           "eai.doe@cor.po",
+		IsGrafanaAdmin:  boolPtr(false),
+		AuthenticatedBy: login.JWTModule,
+		AuthID:          "1234567890",
+		IsDisabled:      false,
+		HelpFlags1:      0,
 		ClientParams: authn.ClientParams{
 			SyncUser:        true,
 			AllowSignUp:     true,
