@@ -1,6 +1,10 @@
 package datasources
 
-import "errors"
+import (
+	"errors"
+
+	"github.com/grafana/grafana/pkg/util/errutil"
+)
 
 var (
 	ErrDataSourceNotFound                = errors.New("data source not found")
@@ -11,4 +15,6 @@ var (
 	ErrDataSourceFailedGenerateUniqueUid = errors.New("failed to generate unique datasource ID")
 	ErrDataSourceIdentifierNotSet        = errors.New("unique identifier and org id are needed to be able to get or delete a datasource")
 	ErrDatasourceIsReadOnly              = errors.New("data source is readonly, can only be updated from configuration")
+	ErrDataSourceNameInvalid             = errutil.NewBase(errutil.StatusValidationFailed, "datasource.nameInvalid", errutil.WithPublicMessage("Invalid datasource name."))
+	ErrDataSourceURLInvalid              = errutil.NewBase(errutil.StatusValidationFailed, "datasource.urlInvalid", errutil.WithPublicMessage("Invalid datasource url."))
 )
