@@ -19,16 +19,15 @@ import (
 
 func TestAlertRuleService(t *testing.T) {
 	ruleService := createAlertRuleService(t)
+	var orgID int64 = 1
 
 	t.Run("alert rule creation should return the created id", func(t *testing.T) {
-		var orgID int64 = 1
 		rule, err := ruleService.CreateAlertRule(context.Background(), dummyRule("test#1", orgID), models.ProvenanceNone, 0)
 		require.NoError(t, err)
 		require.NotEqual(t, 0, rule.ID, "expected to get the created id and not the zero value")
 	})
 
 	t.Run("alert rule creation should set the right provenance", func(t *testing.T) {
-		var orgID int64 = 1
 		rule, err := ruleService.CreateAlertRule(context.Background(), dummyRule("test#2", orgID), models.ProvenanceAPI, 0)
 		require.NoError(t, err)
 
@@ -38,7 +37,6 @@ func TestAlertRuleService(t *testing.T) {
 	})
 
 	t.Run("group creation should set the right provenance", func(t *testing.T) {
-		var orgID int64 = 1
 		group := createDummyGroup("group-test-1", orgID)
 		err := ruleService.ReplaceRuleGroup(context.Background(), orgID, group, 0, models.ProvenanceAPI)
 		require.NoError(t, err)
@@ -54,7 +52,6 @@ func TestAlertRuleService(t *testing.T) {
 	})
 
 	t.Run("alert rule group should be updated correctly", func(t *testing.T) {
-		var orgID int64 = 1
 		rule := dummyRule("test#3", orgID)
 		rule.RuleGroup = "a"
 		rule, err := ruleService.CreateAlertRule(context.Background(), rule, models.ProvenanceNone, 0)
@@ -84,7 +81,6 @@ func TestAlertRuleService(t *testing.T) {
 	})
 
 	t.Run("group creation should propagate group title correctly", func(t *testing.T) {
-		var orgID int64 = 1
 		group := createDummyGroup("group-test-3", orgID)
 		group.Rules[0].RuleGroup = "something different"
 
@@ -100,7 +96,6 @@ func TestAlertRuleService(t *testing.T) {
 	})
 
 	t.Run("alert rule should get interval from existing rule group", func(t *testing.T) {
-		var orgID int64 = 1
 		rule := dummyRule("test#4", orgID)
 		rule.RuleGroup = "b"
 		rule, err := ruleService.CreateAlertRule(context.Background(), rule, models.ProvenanceNone, 0)
@@ -147,7 +142,6 @@ func TestAlertRuleService(t *testing.T) {
 	})
 
 	t.Run("updating a group by updating a rule should bump that rule's data and version number", func(t *testing.T) {
-		var orgID int64 = 1
 		group := createDummyGroup("group-test-5", orgID)
 		err := ruleService.ReplaceRuleGroup(context.Background(), orgID, group, 0, models.ProvenanceAPI)
 		require.NoError(t, err)
@@ -371,7 +365,6 @@ func TestAlertRuleService(t *testing.T) {
 	})
 
 	t.Run("updating a group by updating a rule should not remove dashboard and panel ids", func(t *testing.T) {
-		var orgID int64 = 1
 		dashboardUid := "huYnkl7H"
 		panelId := int64(5678)
 		group := createDummyGroup("group-test-5", orgID)
@@ -520,7 +513,7 @@ func TestAlertRuleService(t *testing.T) {
 		checker.EXPECT().LimitExceeded()
 		ruleService.quotas = checker
 
-		_, err := ruleService.CreateAlertRule(context.Background(), dummyRule("test#1", 1), models.ProvenanceNone, 0)
+		_, err := ruleService.CreateAlertRule(context.Background(), dummyRule("test#1", orgID), models.ProvenanceNone, 0)
 
 		require.ErrorIs(t, err, models.ErrQuotaReached)
 	})
@@ -562,10 +555,10 @@ func createAlertRuleService(t *testing.T) AlertRuleService {
 }
 
 func dummyRule(title string, orgID int64) models.AlertRule {
-	return createTestRule(title, "my-cool-group", orgID)
+	return createTestRule(title, "my-cool-group", orgID, "my-namespace")
 }
 
-func createTestRule(title string, groupTitle string, orgID int64) models.AlertRule {
+func createTestRule(title string, groupTitle string, orgID int64, namespace string) models.AlertRule {
 	return models.AlertRule{
 		OrgID:           orgID,
 		Title:           title,
@@ -583,7 +576,7 @@ func createTestRule(title string, groupTitle string, orgID int64) models.AlertRu
 				},
 			},
 		},
-		NamespaceUID: "my-namespace",
+		NamespaceUID: namespace,
 		RuleGroup:    groupTitle,
 		For:          time.Second * 60,
 		NoDataState:  models.OK,
