@@ -1,10 +1,8 @@
 package oauthtoken
 
 import (
-	"bytes"
 	"context"
 	"errors"
-	"net/http"
 	"reflect"
 	"testing"
 	"time"
@@ -15,7 +13,7 @@ import (
 	"golang.org/x/sync/singleflight"
 
 	"github.com/grafana/grafana/pkg/infra/usagestats"
-	"github.com/grafana/grafana/pkg/login/social"
+	"github.com/grafana/grafana/pkg/login/socialtest"
 	"github.com/grafana/grafana/pkg/services/login"
 	"github.com/grafana/grafana/pkg/services/login/authinfoservice"
 	"github.com/grafana/grafana/pkg/services/user"
@@ -221,12 +219,12 @@ func TestService_TryTokenRefresh_DifferentAuthModuleForUser(t *testing.T) {
 	socialConnector.AssertNotCalled(t, "TokenSource")
 }
 
-func setupOAuthTokenService(t *testing.T) (*Service, *FakeAuthInfoStore, *MockSocialConnector) {
+func setupOAuthTokenService(t *testing.T) (*Service, *FakeAuthInfoStore, *socialtest.MockSocialConnector) {
 	t.Helper()
 
-	socialConnector := &MockSocialConnector{}
-	socialService := &FakeSocialService{
-		connector: socialConnector,
+	socialConnector := &socialtest.MockSocialConnector{}
+	socialService := &socialtest.FakeSocialService{
+		ExpectedConnector: socialConnector,
 	}
 
 	authInfoStore := &FakeAuthInfoStore{}
@@ -239,74 +237,6 @@ func setupOAuthTokenService(t *testing.T) (*Service, *FakeAuthInfoStore, *MockSo
 	}, authInfoStore, socialConnector
 }
 
-type FakeSocialService struct {
-	httpClient *http.Client
-	connector  *MockSocialConnector
-}
-
-func (fss *FakeSocialService) GetOAuthProviders() map[string]bool {
-	panic("not implemented")
-}
-
-func (fss *FakeSocialService) GetOAuthHttpClient(string) (*http.Client, error) {
-	return fss.httpClient, nil
-}
-
-func (fss *FakeSocialService) GetConnector(string) (social.SocialConnector, error) {
-	return fss.connector, nil
-}
-
-func (fss *FakeSocialService) GetOAuthInfoProvider(string) *social.OAuthInfo {
-	panic("not implemented")
-}
-
-func (fss *FakeSocialService) GetOAuthInfoProviders() map[string]*social.OAuthInfo {
-	panic("not implemented")
-}
-
-type MockSocialConnector struct {
-	mock.Mock
-}
-
-func (m *MockSocialConnector) Type() int {
-	args := m.Called()
-	return args.Int(0)
-}
-
-func (m *MockSocialConnector) UserInfo(client *http.Client, token *oauth2.Token) (*social.BasicUserInfo, error) {
-	args := m.Called(client, token)
-	return args.Get(0).(*social.BasicUserInfo), args.Error(1)
-}
-
-func (m *MockSocialConnector) IsEmailAllowed(email string) bool {
-	panic("not implemented")
-}
-
-func (m *MockSocialConnector) IsSignupAllowed() bool {
-	panic("not implemented")
-}
-
-func (m *MockSocialConnector) AuthCodeURL(state string, opts ...oauth2.AuthCodeOption) string {
-	panic("not implemented")
-}
-
-func (m *MockSocialConnector) Exchange(ctx context.Context, code string, authOptions ...oauth2.AuthCodeOption) (*oauth2.Token, error) {
-	panic("not implemented")
-}
-
-func (m *MockSocialConnector) Client(ctx context.Context, t *oauth2.Token) *http.Client {
-	panic("not implemented")
-}
-
-func (m *MockSocialConnector) TokenSource(ctx context.Context, t *oauth2.Token) oauth2.TokenSource {
-	args := m.Called(ctx, t)
-	return args.Get(0).(oauth2.TokenSource)
-}
-
-func (m *MockSocialConnector) SupportBundleContent(bf *bytes.Buffer) error {
-	return nil
-}
-
 type FakeAuthInfoStore struct {
 	login.Store
 	ExpectedError                   error
