@@ -19,6 +19,7 @@ import (
 	"github.com/grafana/grafana/pkg/services/org"
 	"github.com/grafana/grafana/pkg/services/quota"
 	"github.com/grafana/grafana/pkg/services/sqlstore"
+	"github.com/grafana/grafana/pkg/services/store/entity/migrations"
 	"github.com/grafana/grafana/pkg/services/user"
 	"github.com/grafana/grafana/pkg/setting"
 )
@@ -103,6 +104,10 @@ func ProvideService(
 		grafanaStorageLogger.Warn("error loading storage config", "error", err)
 	}
 
+	if err := migrations.MigrateEntityStore(sql, features); err != nil {
+		return nil, err
+	}
+
 	// always exists
 	globalRoots := []storageRuntime{
 		newDiskStorage(RootStorageMeta{
