@@ -4,8 +4,10 @@ import (
 	"errors"
 	"time"
 
+	"github.com/grafana/grafana/pkg/kinds/team"
 	"github.com/grafana/grafana/pkg/services/dashboards"
 	"github.com/grafana/grafana/pkg/services/user"
+	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
 // Typed errors
@@ -23,6 +25,7 @@ var (
 // Team model
 type Team struct {
 	ID    int64  `json:"id" xorm:"pk autoincr 'id'"`
+	UID   string `json:"uid" xorm:"uid"`
 	OrgID int64  `json:"orgId" xorm:"org_id"`
 	Name  string `json:"name"`
 	Email string `json:"email"`
@@ -31,6 +34,18 @@ type Team struct {
 	Updated time.Time `json:"updated"`
 }
 
+func (t *Team) ToResource() team.K8sResource {
+	r := team.NewK8sResource(t.UID, &team.Spec{
+		Name: t.Name,
+	})
+	r.Metadata.CreationTimestamp = v1.NewTime(t.Created)
+	r.Metadata.SetUpdatedTimestamp(&t.Updated)
+	if t.Email != "" {
+		r.Spec.Email = &t.Email
+	}
+	return r
+}
+
 // ---------------------
 // COMMANDS
 
@@ -57,7 +72,6 @@ type GetTeamByIDQuery struct {
 	ID           int64
 	SignedInUser *user.SignedInUser
 	HiddenUsers  map[string]struct{}
-	UserIdFilter int64
 }
 
 // FilterIgnoreUser is used in a get / search teams query when the caller does not want to filter teams by user ID / membership
@@ -75,13 +89,13 @@ type SearchTeamsQuery struct {
 	Limit        int
 	Page         int
 	OrgID        int64 `xorm:"org_id"`
-	UserIDFilter int64 `xorm:"user_id_filter"`
 	SignedInUser *user.SignedInUser
 	HiddenUsers  map[string]struct{}
 }
 
 type TeamDTO struct {
 	ID            int64                     `json:"id" xorm:"id"`
+	UID           string                    `json:"uid" xorm:"uid"`
 	OrgID         int64                     `json:"orgId" xorm:"org_id"`
 	Name          string                    `json:"name"`
 	Email         string                    `json:"email"`
@@ -98,10 +112,6 @@ type SearchTeamQueryResult struct {
 	PerPage    int        `json:"perPage"`
 }
 
-type IsAdminOfTeamsQuery struct {
-	SignedInUser *user.SignedInUser
-}
-
 // TeamMember model
 type TeamMember struct {
 	ID         int64 `xorm:"pk autoincr 'id'"`
@@ -145,6 +155,7 @@ type RemoveTeamMemberCommand struct {
 type GetTeamMembersQuery struct {
 	OrgID        int64
 	TeamID       int64
+	TeamUID      string
 	UserID       int64
 	External     bool
 	SignedInUser *user.SignedInUser
@@ -156,6 +167,7 @@ type GetTeamMembersQuery struct {
 type TeamMemberDTO struct {
 	OrgID      int64                     `json:"orgId" xorm:"org_id"`
 	TeamID     int64                     `json:"teamId" xorm:"team_id"`
+	TeamUID    string                    `json:"teamUID" xorm:"uid"`
 	UserID     int64                     `json:"userId" xorm:"user_id"`
 	External   bool                      `json:"-"`
 	AuthModule string                    `json:"auth_module"`
