@@ -11,10 +11,16 @@ import (
 	"github.com/grafana/grafana-plugin-sdk-go/data"
 )
 
+const cloudWatchTSFormat = "2006-01-02 15:04:05.000"
+
 func logsResultsToDataframes(response *cloudwatchlogs.GetQueryResultsOutput) (*data.Frame, error) {
+	if response == nil {
+		return nil, fmt.Errorf("response is nil, cannot convert log results to data frames")
+	}
+
 	nonEmptyRows := make([][]*cloudwatchlogs.ResultField, 0)
-	// Sometimes CloudWatch can send empty rows
 	for _, row := range response.Results {
+		// Sometimes CloudWatch can send empty rows
 		if len(row) == 0 {
 			continue
 		}
@@ -22,7 +28,7 @@ func logsResultsToDataframes(response *cloudwatchlogs.GetQueryResultsOutput) (*d
 			if row[0].Value == nil {
 				continue
 			}
-			// Sometimes it sends row with only timestamp
+			// Sometimes it sends rows with only timestamp
 			if _, err := time.Parse(cloudWatchTSFormat, *row[0].Value); err == nil {
 				continue
 			}
@@ -48,7 +54,7 @@ func logsResultsToDataframes(response *cloudwatchlogs.GetQueryResultsOutput) (*d
 			if _, exists := fieldValues[*resultField.Field]; !exists {
 				fieldNames = append(fieldNames, *resultField.Field)
 
-				// Check if field is time field
+				// Check if it's a time field
 				if _, err := time.Parse(cloudWatchTSFormat, *resultField.Value); err == nil {
 					fieldValues[*resultField.Field] = make([]*time.Time, rowCount)
 				} else if _, err := strconv.ParseFloat(*resultField.Value, 64); err == nil {
@@ -67,9 +73,14 @@ func logsResultsToDataframes(response *cloudwatchlogs.GetQueryResultsOutput) (*d
 				timeField[i] = &parsedTime
 			} else if numericField, ok := fieldValues[*resultField.Field].([]*float64); ok {
 				parsedFloat, err := strconv.ParseFloat(*resultField.Value, 64)
+
 				if err != nil {
-					return nil, err
+					// This can happen if a field has a mix of numeric and non-numeric values.
+					// In that case, we change the field from a numeric field to a string field.
+					fieldValues[*resultField.Field] = changeToStringField(rowCount, nonEmptyRows[:i+1], *resultField.Field)
+					continue
 				}
+
 				numericField[i] = &parsedFloat
 			} else {
 				fieldValues[*resultField.Field].([]*string)[i] = resultField.Value
@@ -77,7 +88,7 @@ func logsResultsToDataframes(response *cloudwatchlogs.GetQueryResultsOutput) (*d
 		}
 	}
 
-	newFields := make([]*data.Field, 0)
+	newFields := make([]*data.Field, 0, len(fieldNames))
 	for _, fieldName := range fieldNames {
 		newFields = append(newFields, data.NewField(fieldName, nil, fieldValues[fieldName]))
 
@@ -94,12 +105,44 @@ func logsResultsToDataframes(response *cloudwatchlogs.GetQueryResultsOutput) (*d
 		}
 	}
 
+	queryStats := make([]data.QueryStat, 0)
+	if response.Statistics != nil {
+		if response.Statistics.BytesScanned != nil {
+			queryStats = append(queryStats, data.QueryStat{
+				FieldConfig: data.FieldConfig{DisplayName: "Bytes scanned"},
+				Value:       *response.Statistics.BytesScanned,
+			})
+		}
+
+		if response.Statistics.RecordsScanned != nil {
+			queryStats = append(queryStats, data.QueryStat{
+				FieldConfig: data.FieldConfig{DisplayName: "Records scanned"},
+				Value:       *response.Statistics.RecordsScanned,
+			})
+		}
+
+		if response.Statistics.RecordsMatched != nil {
+			queryStats = append(queryStats, data.QueryStat{
+				FieldConfig: data.FieldConfig{DisplayName: "Records matched"},
+				Value:       *response.Statistics.RecordsMatched,
+			})
+		}
+	}
+
 	frame := data.NewFrame("CloudWatchLogsResponse", newFields...)
 	frame.Meta = &data.FrameMeta{
-		Custom: map[string]interface{}{
-			"Status":     *response.Status,
-			"Statistics": *response.Statistics,
-		},
+		Stats:  nil,
+		Custom: nil,
+	}
+
+	if len(queryStats) > 0 {
+		frame.Meta.Stats = queryStats
+	}
+
+	if response.Status != nil {
+		frame.Meta.Custom = map[string]interface{}{
+			"Status": *response.Status,
+		}
 	}
 
 	// Results aren't guaranteed to come ordered by time (ascending), so we need to sort
@@ -107,8 +150,22 @@ func logsResultsToDataframes(response *cloudwatchlogs.GetQueryResultsOutput) (*d
 	return frame, nil
 }
 
-func groupResults(results *data.Frame, groupingFieldNames []string) ([]*data.Frame, error) {
+func changeToStringField(lengthOfValues int, rows [][]*cloudwatchlogs.ResultField, logEventField string) []*string {
+	fieldValuesAsStrings := make([]*string, lengthOfValues)
+	for i, resultFields := range rows {
+		for _, field := range resultFields {
+			if *field.Field == logEventField {
+				fieldValuesAsStrings[i] = field.Value
+			}
+		}
+	}
+
+	return fieldValuesAsStrings
+}
+
+func groupResults(results *data.Frame, groupingFieldNames []string, removeNonTime bool) ([]*data.Frame, error) {
 	groupingFields := make([]*data.Field, 0)
+	removeFieldIndices := make([]int, 0)
 
 	for i, field := range results.Fields {
 		for _, groupingField := range groupingFieldNames {
@@ -122,6 +179,10 @@ func groupResults(results *data.Frame, groupingFieldNames []string) ([]*data.Fra
 					results.Fields[i] = newField
 					field = newField
 				}
+				// For expressions and alerts to work properly we need to remove non-time grouping fields
+				if removeNonTime && !field.Type().Time() {
+					removeFieldIndices = append(removeFieldIndices, i)
+				}
 
 				groupingFields = append(groupingFields, field)
 			}
@@ -136,13 +197,19 @@ func groupResults(results *data.Frame, groupingFieldNames []string) ([]*data.Fra
 	groupedDataFrames := make(map[string]*data.Frame)
 	for i := 0; i < rowLength; i++ {
 		groupKey := generateGroupKey(groupingFields, i)
+		// if group key doesn't exist create it
 		if _, exists := groupedDataFrames[groupKey]; !exists {
 			newFrame := results.EmptyCopy()
 			newFrame.Name = groupKey
+			newFrame.Meta = results.Meta
+			// remove grouping indices
+			newFrame.Fields = removeFieldsByIndex(newFrame.Fields, removeFieldIndices)
 			groupedDataFrames[groupKey] = newFrame
 		}
 
-		groupedDataFrames[groupKey].AppendRow(results.RowCopy(i)...)
+		// add row to frame
+		row := copyRowWithoutValues(results, i, removeFieldIndices)
+		groupedDataFrames[groupKey].AppendRow(row...)
 	}
 
 	newDataFrames := make([]*data.Frame, 0, len(groupedDataFrames))
@@ -153,6 +220,40 @@ func groupResults(results *data.Frame, groupingFieldNames []string) ([]*data.Fra
 	return newDataFrames, nil
 }
 
+// remove fields at the listed indices
+func removeFieldsByIndex(fields []*data.Field, removeIndices []int) []*data.Field {
+	newGroupingFields := make([]*data.Field, 0)
+	removeIndicesIndex := 0
+	for i, field := range fields {
+		if removeIndicesIndex < len(removeIndices) && i == removeIndices[removeIndicesIndex] {
+			removeIndicesIndex++
+			if removeIndicesIndex > len(removeIndices) {
+				newGroupingFields = append(newGroupingFields, fields[i+1:]...)
+				break
+			}
+			continue
+		}
+		newGroupingFields = append(newGroupingFields, field)
+	}
+	return newGroupingFields
+}
+
+// copy a row without the listed values
+func copyRowWithoutValues(f *data.Frame, rowIdx int, removeIndices []int) []interface{} {
+	vals := make([]interface{}, len(f.Fields)-len(removeIndices))
+	valsIdx := 0
+	removeIndicesIndex := 0
+	for i := range f.Fields {
+		if removeIndicesIndex < len(removeIndices) && i == removeIndices[removeIndicesIndex] {
+			removeIndicesIndex++
+			continue
+		}
+		vals[valsIdx] = f.CopyAt(i, rowIdx)
+		valsIdx++
+	}
+	return vals
+}
+
 func generateGroupKey(fields []*data.Field, row int) string {
 	groupKey := ""
 	for _, field := range fields {
