@@ -26,6 +26,10 @@ func (e *cloudWatchExecutor) newResourceMux() *http.ServeMux {
 	mux.HandleFunc("/accounts", routes.ResourceRequestMiddleware(routes.AccountsHandler, logger, e.getRequestContext))
 	mux.HandleFunc("/namespaces", routes.ResourceRequestMiddleware(routes.NamespacesHandler, logger, e.getRequestContext))
 	mux.HandleFunc("/log-group-fields", routes.ResourceRequestMiddleware(routes.LogGroupFieldsHandler, logger, e.getRequestContext))
+
+	// remove this once AWS's Cross Account Observability is supported in GovCloud
+	mux.HandleFunc("/legacy-log-groups", handleResourceReq(e.handleGetLogGroups))
+
 	return mux
 }
 
