@@ -1,14 +1,11 @@
-export type ContextMenuData = {
-  e: MouseEvent;
-  levelIndex: number;
-  barIndex: number;
-};
+import { LevelItem } from './FlameGraph/dataTransform';
 
-export type Metadata = {
-  percentValue: number;
-  unitTitle: string;
-  unitValue: string;
-  samples: string;
+export type ClickedItemData = {
+  posX: number;
+  posY: number;
+  label: string;
+  item: LevelItem;
+  level: number;
 };
 
 export enum SampleUnit {
@@ -44,3 +41,10 @@ export type TopTableValue = {
   value: number;
   unitValue: string;
 };
+
+export enum ColorScheme {
+  ValueBased = 'valueBased',
+  PackageBased = 'packageBased',
+}
+
+export type TextAlign = 'left' | 'right';
